summaryrefslogtreecommitdiff
path: root/libavcodec/atrac3plus.h
diff options
context:
space:
mode:
authorAlexandra Hájková <alexandra@khirnov.net>2016-04-09 14:47:04 +0200
committerAnton Khirnov <anton@khirnov.net>2016-11-18 10:33:59 +0100
commitedd4c19a781124cbdb3598f94ec3a0d9ff7058cd (patch)
tree71f8636b7e554d6e68eafffccabcf6068591e47c /libavcodec/atrac3plus.h
parent027211920222b2b63ca07d712b3771a14add9aab (diff)
atrac3plus: Convert to the new bitstream reader
Signed-off-by: Anton Khirnov <anton@khirnov.net>
Diffstat (limited to 'libavcodec/atrac3plus.h')
-rw-r--r--libavcodec/atrac3plus.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/libavcodec/atrac3plus.h b/libavcodec/atrac3plus.h
index e56c4441b6..cca399adab 100644
--- a/libavcodec/atrac3plus.h
+++ b/libavcodec/atrac3plus.h
@@ -31,10 +31,11 @@
#include <stdint.h>
#include "libavutil/float_dsp.h"
+
#include "atrac.h"
+#include "bitstream.h"
#include "avcodec.h"
#include "fft.h"
-#include "get_bits.h"
/** Global unit sizes */
#define ATRAC3P_SUBBANDS 16 ///< number of PQF subbands
@@ -163,13 +164,13 @@ void ff_atrac3p_init_vlcs(AVCodec *codec);
/**
* Decode bitstream data of a channel unit.
*
* @param[in] gb the GetBit context
* @param[in,out] ctx ptr to the channel unit context
* @param[in] num_channels number of channels to process
* @param[in] avctx ptr to the AVCodecContext
* @return result code: 0 = OK, otherwise - error code
*/
-int ff_atrac3p_decode_channel_unit(GetBitContext *gb, Atrac3pChanUnitCtx *ctx,
+int ff_atrac3p_decode_channel_unit(BitstreamContext *bc, Atrac3pChanUnitCtx *ctx,
int num_channels, AVCodecContext *avctx);
/**
@@ -163,13 +164,13 @@ void ff_atrac3p_init_vlcs(AVCodec *codec);
* Decode bitstream data of a channel unit.
*
- * @param[in] gb the GetBit context
+ * @param[in] bc the Bitstream context
* @param[in,out] ctx ptr to the channel unit context
* @param[in] num_channels number of channels to process